@@ -154,6 +154,19 @@ assert_is_expression <- function(x,
   )
 }
 
+#' @rdname is_externalptr
+#' @export
+assert_is_externalptr <- function(x, 
+  severity = getOption("assertive.severity", "stop"))
+{                                                         
+  assert_engine(
+    is_externalptr, 
+    x, 
+    .xname = get_name_in_parent(x),
+    severity = severity
+  )
+}
+
 #' @rdname is_factor
 #' @export
 assert_is_factor <- function(x, 
@@ -284,6 +297,19 @@ assert_is_ordered <- function(x,
   )
 }
 
+#' @rdname is_list
+#' @export
+assert_is_pairlist <- function(x, 
+  severity = getOption("assertive.severity", "stop"))
+{                                                         
+  assert_engine(
+    is_pairlist, 
+    x, 
+    .xname = get_name_in_parent(x),
+    severity = severity
+  )
+}
+
 #' @rdname is_function
 #' @export
 assert_is_primitive <- function(x, 
